public inbox for devel@edk2.groups.io
 help / color / mirror / Atom feed
From: Gary Lin <glin@suse.com>
To: edk2-devel@lists.01.org
Cc: Jeff Fan <jeff.fan@intel.com>
Subject: [PATCH 10/33] IntelFrameworkModulePkg: Fix typos in comments
Date: Wed, 19 Oct 2016 15:01:15 +0800	[thread overview]
Message-ID: <20161019070138.16424-11-glin@suse.com> (raw)
In-Reply-To: <20161019070138.16424-1-glin@suse.com>

- stoping -> stopping
- Pointion -> Position
- Arrary -> Array
- reseting -> resetting
- excute -> execute
- isTRUE -> is TRUE
- connectted -> connected
- Retrive -> Retrieve
- dirvers -> drivers
- funciton -> function
- paramter -> parameter
- availible -> available
- permenent -> permanent
- boundry -> boundary

Cc: Jeff Fan <jeff.fan@intel.com>
Contributed-under: TianoCore Contribution Agreement 1.0
Signed-off-by: Gary Lin <glin@suse.com>
---
 IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdCtrller.c                                               |  4 +-
 IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.c                                                 |  4 +-
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.c                                         | 12 ++--
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.h                                         | 12 ++--
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.c                         |  6 +-
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.h                         |  8 +--
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.c                                                        | 12 ++--
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.h                                                        | 12 ++--
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.c                                                       |  6 +-
 IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.h                                                       |  8 +--
 IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.c                                             | 12 ++--
 IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.h                                             |  2 +-
 IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.c                                                   | 14 ++---
 IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.h                                                   | 62 ++++++++++----------
 IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/Misc.c                                                        |  2 +-
 IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/PxeUndi.c                                                     | 46 +++++++--------
 IntelFrameworkModulePkg/Csm/LegacyBiosDxe/Ipf/IpfBootSupport.c                                               |  2 +-
 IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyBiosInterface.h                                              |  4 +-
 IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyPci.c                                                        |  4 +-
 IntelFrameworkModulePkg/Include/Library/GenericBdsLib.h                                                      |  4 +-
 IntelFrameworkModulePkg/Include/Library/PlatformBdsLib.h                                                     |  2 +-
 IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.c          |  8 +--
 IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLibInternals.h |  4 +-
 IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c                                               |  2 +-
 IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c                                            |  2 +-
 IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.c                                             |  2 +-
 IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.h                                             |  2 +-
 IntelFrameworkModulePkg/Universal/DataHubDxe/DataHub.c                                                       |  4 +-
 IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErr.c                                           |  2 +-
 IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVol.c                                            |  6 +-
 IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVolWrite.c                                       |  4 +-
 31 files changed, 137 insertions(+), 137 deletions(-)

diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdCtrller.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdCtrller.c
index 2a20b78..9bde538 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdCtrller.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2KbdCtrller.c
@@ -1685,9 +1685,9 @@ InitKeyboard (
 
   ConsoleIn->IsSupportPartialKey = FALSE;
   //
-  // For reseting keyboard is not mandatory before booting OS and sometimes keyboard responses very slow,
+  // For resetting keyboard is not mandatory before booting OS and sometimes keyboard responses very slow,
   // and to support KB hot plug, we need to let the InitKB succeed no matter whether there is a KB device connected
-  // to system. So we only do the real reseting for keyboard when user asks and there is a real KB connected t system,
+  // to system. So we only do the real resetting for keyboard when user asks and there is a real KB connected t system,
   // and normally during booting an OS, it's skipped.
   //
   if (ExtendedVerification && CheckKeyboardConnect (ConsoleIn)) {
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.c
index c020202..b6a9b70 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2KeyboardDxe/Ps2Keyboard.c
@@ -55,7 +55,7 @@ KbdControllerDriverStart (
   );
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
@@ -448,7 +448,7 @@ ErrorExit:
 }
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.c
index fb4a753..5aa1705 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.c
@@ -540,7 +540,7 @@ PS2MouseRead (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Command I/O command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -579,7 +579,7 @@ Out8042Command (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -615,7 +615,7 @@ Out8042Data (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -659,7 +659,7 @@ In8042Data (
   @param Command Aux I/O command
   @param Resend  Whether need resend the Aux command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -740,7 +740,7 @@ Out8042AuxCommand (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value  
   
-  @retval EFI_SUCCESS Success to excute I/O work flow.
+  @retval EFI_SUCCESS Success to execute I/O work flow.
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -786,7 +786,7 @@ Out8042AuxData (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.h b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.h
index 59d7b51..560389d 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.h
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/CommPs2.h
@@ -302,7 +302,7 @@ PS2MouseRead (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Command I/O command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -317,7 +317,7 @@ Out8042Command (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -332,7 +332,7 @@ In8042Data (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -348,7 +348,7 @@ Out8042Data (
   @param Command Aux I/O command
   @param Resend  Whether need resend the Aux command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -364,7 +364,7 @@ Out8042AuxCommand (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -379,7 +379,7 @@ In8042AuxData (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.c
index 7af35bc..bf8adfc 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.c
@@ -402,7 +402,7 @@ ErrorExit:
 }
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
@@ -498,14 +498,14 @@ PS2MouseAbsolutePointerDriverStop (
 }
 
 /**
-  Reset the Mouse and do BAT test for it, if ExtendedVerification isTRUE and there is a mouse device connectted to system.
+  Reset the Mouse and do BAT test for it, if ExtendedVerification is TRUE and there is a mouse device connected to system.
 
   @param This                 - Pointer of simple pointer Protocol.
   @param ExtendedVerification - Whether configure mouse parameters. True: do; FALSE: skip.
 
 
   @retval EFI_SUCCESS         - The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR    - Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR    - Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.h b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.h
index 17d1847..8f959fd 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.h
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseAbsolutePointerDxe/Ps2MouseAbsolutePointer.h
@@ -151,7 +151,7 @@ PS2MouseAbsolutePointerDriverStart (
   );
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
@@ -303,14 +303,14 @@ Ps2MouseAbsolutePointerComponentNameGetControllerName (
   );
 
 /**
-  Reset the Mouse and do BAT test for it, if ExtendedVerification isTRUE and there is a mouse device connectted to system.
+  Reset the Mouse and do BAT test for it, if ExtendedVerification is TRUE and there is a mouse device connected to system.
 
   @param This                 - Pointer of simple pointer Protocol.
   @param ExtendedVerification - Whether configure mouse parameters. True: do; FALSE: skip.
 
 
   @retval EFI_SUCCESS         - The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR    - Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR    - Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
@@ -374,7 +374,7 @@ PollMouseAbsolutePointer (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.c
index 1c763e9..27d378d 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.c
@@ -539,7 +539,7 @@ PS2MouseRead (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Command I/O command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -578,7 +578,7 @@ Out8042Command (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -614,7 +614,7 @@ Out8042Data (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -658,7 +658,7 @@ In8042Data (
   @param Command Aux I/O command
   @param Resend  Whether need resend the Aux command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -739,7 +739,7 @@ Out8042AuxCommand (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -785,7 +785,7 @@ Out8042AuxData (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.h b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.h
index a48ee8c..6c0f8ac 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.h
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/CommPs2.h
@@ -302,7 +302,7 @@ PS2MouseRead (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Command I/O command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -317,7 +317,7 @@ Out8042Command (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -332,7 +332,7 @@ In8042Data (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -348,7 +348,7 @@ Out8042Data (
   @param Command Aux I/O command
   @param Resend  Whether need resend the Aux command.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -364,7 +364,7 @@ Out8042AuxCommand (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value.
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
@@ -379,7 +379,7 @@ In8042AuxData (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Buffer holding return value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.c b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.c
index 1623201..43fad21 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.c
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.c
@@ -417,7 +417,7 @@ ErrorExit:
 }
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
@@ -513,14 +513,14 @@ PS2MouseDriverStop (
 }
 
 /**
-  Reset the Mouse and do BAT test for it, if ExtendedVerification isTRUE and there is a mouse device connectted to system
+  Reset the Mouse and do BAT test for it, if ExtendedVerification is TRUE and there is a mouse device connected to system
 
   @param This                 - Pointer of simple pointer Protocol.
   @param ExtendedVerification - Whether configure mouse parameters. True: do; FALSE: skip.
 
 
   @retval EFI_SUCCESS         - The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR    - Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR    - Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.h b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.h
index 1d9f139..078cefa 100644
--- a/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.h
+++ b/IntelFrameworkModulePkg/Bus/Isa/Ps2MouseDxe/Ps2Mouse.h
@@ -151,7 +151,7 @@ PS2MouseDriverStart (
   );
 
 /**
-  Stop this driver on ControllerHandle. Support stoping any child handles
+  Stop this driver on ControllerHandle. Support stopping any child handles
   created by this driver.
 
   @param  This              Protocol instance pointer.
@@ -303,14 +303,14 @@ Ps2MouseComponentNameGetControllerName (
   );
 
 /**
-  Reset the Mouse and do BAT test for it, if ExtendedVerification isTRUE and there is a mouse device connectted to system
+  Reset the Mouse and do BAT test for it, if ExtendedVerification is TRUE and there is a mouse device connected to system
 
   @param This                 - Pointer of simple pointer Protocol.
   @param ExtendedVerification - Whether configure mouse parameters. True: do; FALSE: skip.
 
 
   @retval EFI_SUCCESS         - The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR    - Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR    - Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
@@ -374,7 +374,7 @@ PollMouse (
   @param IsaIo   Pointer to instance of EFI_ISA_IO_PROTOCOL
   @param Data    Data value
   
-  @retval EFI_SUCCESS Success to excute I/O work flow
+  @retval EFI_SUCCESS Success to execute I/O work flow
   @retval EFI_TIMEOUT Keyboard controller time out.
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.h b/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.h
index a27d2e1..e836086 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.h
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.h
@@ -447,7 +447,7 @@ BiosKeyboardComponentNameGetControllerName (
   @param  ExtendedVerification  Whether perform the extra validation of keyboard. True: perform; FALSE: skip.
 
   @retval EFI_SUCCESS           The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR      Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR      Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.c b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.c
index 7af2ded..a2a7797 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.c
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.c
@@ -2148,7 +2148,7 @@ Undi16SimpleNetworkInitialize (
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
   @param ExtendedVerification Need extended verfication.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -2229,7 +2229,7 @@ Undi16SimpleNetworkReset (
 
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -2342,7 +2342,7 @@ Undi16SimpleNetworkShutdown (
   @param MCastFilterCnt       Count of mutli cast filter for different MAC address
   @param MCastFilter          Buffer for mustli cast filter for different MAC address.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -2496,10 +2496,10 @@ Undi16SimpleNetworkReceiveFilters (
   Set new MAC address.
 
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
-  @param Reset                Whether reset station MAC address to permenent address
+  @param Reset                Whether reset station MAC address to permanent address
   @param New                  A pointer to New address
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -2554,7 +2554,7 @@ Undi16SimpleNetworkStationAddress (
 
   if (Reset) {
     //
-    // If we are reseting the Station Address to the permanent address, and the
+    // If we are resetting the Station Address to the permanent address, and the
     // Station Address is not programmable, then just return EFI_SUCCESS.
     //
     if (!SimpleNetworkDevice->SimpleNetworkMode.MacAddressChangeable) {
@@ -2853,7 +2853,7 @@ Undi16SimpleNetworkStatistics (
   @param IP                   A pointer to given Ip address.
   @param MAC                  On return, translated MAC address.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_INVALID_PARAMETER Invalid IP address.
   @retval EFI_INVALID_PARAMETER Invalid return buffer for holding MAC address.
   @retval EFI_UNSUPPORTED       Do not support IPv6 
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.h b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.h
index b29059f..447783c 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.h
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/BiosSnp16.h
@@ -236,7 +236,7 @@ Undi16SimpleNetworkInitialize (
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
   @param ExtendedVerification Need extended verfication.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -255,7 +255,7 @@ Undi16SimpleNetworkReset (
 
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -278,7 +278,7 @@ Undi16SimpleNetworkShutdown (
   @param MCastFilterCnt       Count of mutli cast filter for different MAC address
   @param MCastFilter          Buffer for mustli cast filter for different MAC address.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -300,10 +300,10 @@ Undi16SimpleNetworkReceiveFilters (
   Set new MAC address.
 
   @param This                 A pointer to EFI_SIMPLE_NETWORK_PROTOCOL structure.
-  @param Reset                Whether reset station MAC address to permenent address
+  @param Reset                Whether reset station MAC address to permanent address
   @param New                  A pointer to New address
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -326,7 +326,7 @@ Undi16SimpleNetworkStationAddress (
   @param StatisticsSize       The buffer of statistics table.
   @param StatisticsTable      A pointer to statistics buffer.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_DEVICE_ERROR      Network device has not been initialized.
   @retval EFI_NOT_STARTED       Network device has been stopped.
   @retval EFI_DEVICE_ERROR      Invalid status for network device
@@ -350,7 +350,7 @@ Undi16SimpleNetworkStatistics (
   @param IP                   A pointer to given Ip address.
   @param MAC                  On return, translated MAC address.
   
-  @retval EFI_INVALID_PARAMETER Invalid This paramter.
+  @retval EFI_INVALID_PARAMETER Invalid This parameter.
   @retval EFI_INVALID_PARAMETER Invalid IP address.
   @retval EFI_INVALID_PARAMETER Invalid return buffer for holding MAC address.
   @retval EFI_UNSUPPORTED       Do not support IPv6 
@@ -639,7 +639,7 @@ LaunchBaseCode (
   Status: See the PXENV_STATUS_xxx constants.    
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call.                                
@@ -680,7 +680,7 @@ PxeStartUndi (
   Status: See the PXENV_STATUS_xxx constants.
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call.    
@@ -713,7 +713,7 @@ PxeUndiStartup (
   Status: See the PXENV_STATUS_xxx constants.
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call. 
@@ -759,7 +759,7 @@ PxeUndiCleanup (
   Status: See the PXENV_STATUS_xxx constants.    
   
   @param  SimpleNetworkDevice   Device instance.
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call. 
@@ -808,7 +808,7 @@ PxeUndiInitialize (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance.
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
   @param  RxFilter             Filter setting mask value for PXE recive .     
                                
@@ -843,7 +843,7 @@ PxeUndiResetNic (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.   
@@ -890,7 +890,7 @@ PxeUndiShutdown (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -921,7 +921,7 @@ PxeUndiOpen (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1007,7 +1007,7 @@ PxeUndiClose (
   Status: See the PXENV_STATUS_xxx constants  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1041,7 +1041,7 @@ PxeUndiTransmit (
   Status: See the PXENV_STATUS_xxx constants        
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1076,7 +1076,7 @@ PxeUndiSetMcastAddr (
   Status: See the PXENV_STATUS_xxx constants.     
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1110,7 +1110,7 @@ PxeUndiSetStationAddr (
   Status: See the PXENV_STATUS_xxx constants.   
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1169,7 +1169,7 @@ PxeUndiSetPacketFilter (
   TxBufCnt: Transmit queue length.  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1210,7 +1210,7 @@ PxeUndiGetInformation (
   because receive queue was full.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1240,7 +1240,7 @@ PxeUndiGetStatistics (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1271,7 +1271,7 @@ PxeUndiClearStatistics (
   Status: See the PXENV_STATUS_xxx constants.    
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1308,7 +1308,7 @@ PxeUndiInitiateDiags (
   Status: See the PXENV_STATUS_xxx constants.  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1342,7 +1342,7 @@ PxeUndiForceInterrupt (
   MediaAddr: MAC multicast address.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1408,7 +1408,7 @@ PxeUndiGetMcastAddr (
   in the [PnP] and [PCI] specifications    
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1457,7 +1457,7 @@ PxeUndiGetNicType (
   Reserved: Must be zero.       
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1515,7 +1515,7 @@ PxeUndiGetNdisInfo (
   strategy routine when the UNDI re-enables interrupts.   
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1550,7 +1550,7 @@ PxeUndiIsr (
   Status: See the PXENV_STATUS_xxx constants.      
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1598,7 +1598,7 @@ PxeUndiStop (
   status of that operation on return.     
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1623,7 +1623,7 @@ PxeUndiGetState (
 
   @param SimpleNetworkDevice    Device instance for simple network
   @param Table                 Point to parameter/retun value table for legacy far call
-  @param TableSize              The size of paramter/return value table
+  @param TableSize              The size of parameter/return value table
   @param CallIndex              The index of legacy call.
   
   @return EFI_STATUS 
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/Misc.c b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/Misc.c
index 243048c..4750b2f 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/Misc.c
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/Misc.c
@@ -823,7 +823,7 @@ LaunchBaseCode (
 
   @param SimpleNetworkDevice    Device instance for simple network
   @param Table                 Point to parameter/retun value table for legacy far call
-  @param TableSize              The size of paramter/return value table
+  @param TableSize              The size of parameter/return value table
   @param CallIndex              The index of legacy call.
   
   @return EFI_STATUS 
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/PxeUndi.c b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/PxeUndi.c
index d35fc3f..7063229 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/PxeUndi.c
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/Snp16Dxe/PxeUndi.c
@@ -57,7 +57,7 @@ WITHOUT WARRANTIES OR REPRESENTATIONS OF ANY KIND, EITHER EXPRESS OR IMPLIED.
   Status: See the PXENV_STATUS_xxx constants.    
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call.                                
@@ -105,7 +105,7 @@ PxeStartUndi (
   Status: See the PXENV_STATUS_xxx constants.
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call.    
@@ -145,7 +145,7 @@ PxeUndiStartup (
   Status: See the PXENV_STATUS_xxx constants.
 
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call. 
@@ -198,7 +198,7 @@ PxeUndiCleanup (
   Status: See the PXENV_STATUS_xxx constants.    
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                                 
   @return Return value of PXE option ROM far call. 
@@ -254,7 +254,7 @@ PxeUndiInitialize (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance.
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
   @param  RxFilter             Filter setting mask value for PXE recive .     
                                
@@ -347,7 +347,7 @@ PxeUndiResetNic (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.   
@@ -401,7 +401,7 @@ PxeUndiShutdown (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -439,7 +439,7 @@ PxeUndiOpen (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -532,7 +532,7 @@ PxeUndiClose (
   Status: See the PXENV_STATUS_xxx constants  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -586,7 +586,7 @@ PxeUndiTransmit (
   Status: See the PXENV_STATUS_xxx constants        
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -628,7 +628,7 @@ PxeUndiSetMcastAddr (
   Status: See the PXENV_STATUS_xxx constants.     
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -669,7 +669,7 @@ PxeUndiSetStationAddr (
   Status: See the PXENV_STATUS_xxx constants.   
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -735,7 +735,7 @@ PxeUndiSetPacketFilter (
   TxBufCnt: Transmit queue length.  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -783,7 +783,7 @@ PxeUndiGetInformation (
   because receive queue was full.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -820,7 +820,7 @@ PxeUndiGetStatistics (
   Status: See the PXENV_STATUS_xxx constants.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -858,7 +858,7 @@ PxeUndiClearStatistics (
   Status: See the PXENV_STATUS_xxx constants.    
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -902,7 +902,7 @@ PxeUndiInitiateDiags (
   Status: See the PXENV_STATUS_xxx constants.  
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -943,7 +943,7 @@ PxeUndiForceInterrupt (
   MediaAddr: MAC multicast address.
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1016,7 +1016,7 @@ PxeUndiGetMcastAddr (
   in the [PnP] and [PCI] specifications    
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1072,7 +1072,7 @@ PxeUndiGetNicType (
   Reserved: Must be zero.       
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1137,7 +1137,7 @@ PxeUndiGetNdisInfo (
   strategy routine when the UNDI re-enables interrupts.   
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1179,7 +1179,7 @@ PxeUndiIsr (
   Status: See the PXENV_STATUS_xxx constants.      
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
@@ -1234,7 +1234,7 @@ PxeUndiStop (
   status of that operation on return.     
   
   @param  SimpleNetworkDevice   Device instance
-  @param  PxeUndiTable          Point to structure which hold paramter and return value 
+  @param  PxeUndiTable          Point to structure which hold parameter and return value 
                                 for option ROM call.
                               
   @return Return value of PXE option ROM far call.  
diff --git a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/Ipf/IpfBootSupport.c b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/Ipf/IpfBootSupport.c
index 8c8f6d3..ee08c86 100644
--- a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/Ipf/IpfBootSupport.c
+++ b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/Ipf/IpfBootSupport.c
@@ -223,7 +223,7 @@ RelocateImageUnder4GIfNeeded (
       }
       ImageContext.ImageAddress = (PHYSICAL_ADDRESS)MemoryAddress;
       //
-      // Align buffer on section boundry
+      // Align buffer on section boundary
       //
       ImageContext.ImageAddress += ImageContext.SectionAlignment - 1;
      ImageContext.ImageAddress &= ~((PHYSICAL_ADDRESS)ImageContext.SectionAlignment - 1);
diff --git a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyBiosInterface.h b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyBiosInterface.h
index bbd074b..069646b 100644
--- a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyBiosInterface.h
+++ b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyBiosInterface.h
@@ -826,7 +826,7 @@ LegacyBiosFarCall86 (
   @param  RomSize                Size of ROM Image
   @param  Flags                  Indicates if ROM found and if PC-AT.
 
-  @retval EFI_SUCCESS            Legacy Option ROM availible for this device
+  @retval EFI_SUCCESS            Legacy Option ROM available for this device
   @retval EFI_UNSUPPORTED        Legacy Option ROM not supported.
 
 **/
@@ -1463,7 +1463,7 @@ LegacyCalculateWriteStandardCmosChecksum (
   @param[out] OpromRevision          Revision of the PCI Rom
   @param[out] ConfigUtilityCodeHeaderPointer of Configuration Utility Code Header
 
-  @return EFI_SUCCESS            Legacy Option ROM availible for this device
+  @return EFI_SUCCESS            Legacy Option ROM available for this device
   @return EFI_ALREADY_STARTED    This device is already managed by its Oprom
   @return EFI_UNSUPPORTED        Legacy Option ROM not supported.
 
diff --git a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyPci.c b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyPci.c
index 9d84ab0..8f91a7d 100644
--- a/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyPci.c
+++ b/IntelFrameworkModulePkg/Csm/LegacyBiosDxe/LegacyPci.c
@@ -1812,7 +1812,7 @@ PciShadowRoms (
   @param  RomSize                Size of ROM Image
   @param  Flags                  Indicates if ROM found and if PC-AT.
 
-  @retval EFI_SUCCESS            Legacy Option ROM availible for this device
+  @retval EFI_SUCCESS            Legacy Option ROM available for this device
   @retval EFI_UNSUPPORTED        Legacy Option ROM not supported.
 
 **/
@@ -1854,7 +1854,7 @@ LegacyBiosCheckPciRom (
     @param[out] OpromRevision          Revision of the PCI Rom
     @param[out] ConfigUtilityCodeHeaderPointer of Configuration Utility Code Header
 
-    @return EFI_SUCCESS            Legacy Option ROM availible for this device
+    @return EFI_SUCCESS            Legacy Option ROM available for this device
     @return EFI_ALREADY_STARTED    This device is already managed by its Oprom
     @return EFI_UNSUPPORTED        Legacy Option ROM not supported.
 
diff --git a/IntelFrameworkModulePkg/Include/Library/GenericBdsLib.h b/IntelFrameworkModulePkg/Include/Library/GenericBdsLib.h
index ecd68a0..c338c4d 100644
--- a/IntelFrameworkModulePkg/Include/Library/GenericBdsLib.h
+++ b/IntelFrameworkModulePkg/Include/Library/GenericBdsLib.h
@@ -170,7 +170,7 @@ BdsLibBootViaBootOption (
   This function will enumerate all possible boot devices in the system, and
   automatically create boot options for Network, Shell, Removable BlockIo, 
   and Non-BlockIo Simplefile devices.
-  It will excute once every boot.
+  It will execute once every boot.
   
   @param  BdsBootOptionList      The header of the linked list that indexed all
                                  current boot options.
@@ -995,7 +995,7 @@ BdsLibUserIdentify (
 /**
   This function checks if a Fv file device path is valid, according to a file GUID. If it is invalid,
   it tries to return the valid device path.
-  FV address maybe changes for memory layout adjust from time to time, use this funciton
+  FV address maybe changes for memory layout adjust from time to time, use this function
   could promise the Fv file device path is right.
 
   @param  DevicePath             On input, the Fv file device path to check. On
diff --git a/IntelFrameworkModulePkg/Include/Library/PlatformBdsLib.h b/IntelFrameworkModulePkg/Include/Library/PlatformBdsLib.h
index af237a6..f971e67 100644
--- a/IntelFrameworkModulePkg/Include/Library/PlatformBdsLib.h
+++ b/IntelFrameworkModulePkg/Include/Library/PlatformBdsLib.h
@@ -72,7 +72,7 @@ PlatformBdsInit (
   );
 
 /**
-  The function will excute with as the platform policy, current policy
+  The function will execute with as the platform policy, current policy
   is driven by boot mode. IBV/OEM can customize this code for their specific
   policy action.
 
diff --git a/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLibInternals.h b/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLibInternals.h
index 6ba3f43..3992875 100644
--- a/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLibInternals.h
+++ b/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLibInternals.h
@@ -1,5 +1,5 @@
 /** @file
-  Internal data structure and interfaces defintions for UEFI and Tiano Decompress Libary.
+  Internal data structure and interfaces defintions for UEFI and Tiano Decompress Library.
 
   Copyright (c) 2006 - 2009, Intel Corporation. All rights reserved.<BR>
   This program and the accompanying materials
@@ -155,7 +155,7 @@ DecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
index d4b4475..96f84ec 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/BootMaint.c
@@ -739,7 +739,7 @@ BootMaintCallback (
 
   Private      = BMM_CALLBACK_DATA_FROM_THIS (This);
   //
-  // Retrive uncommitted data from Form Browser
+  // Retrieve uncommitted data from Form Browser
   //
   CurrentFakeNVMap = &Private->BmmFakeNvData;
   HiiGetBrowserData (&gBootMaintFormSetGuid, mBootMaintStorageName, sizeof (BMM_FAKE_NV_DATA), (UINT8 *) CurrentFakeNVMap);
diff --git a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
index f804984..910edf6 100644
--- a/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
+++ b/IntelFrameworkModulePkg/Universal/BdsDxe/BootMaint/FileExplorer.c
@@ -370,7 +370,7 @@ FileExplorerRouteConfig (
   @retval  EFI_OUT_OF_RESOURCES  Not enough storage is available to hold the variable and its data.
   @retval  EFI_DEVICE_ERROR      The variable could not be saved.
   @retval  EFI_UNSUPPORTED       The specified Action is not supported by the callback.
-  @retval  EFI_INVALID_PARAMETER If paramter Value or ActionRequest is NULL.
+  @retval  EFI_INVALID_PARAMETER If parameter Value or ActionRequest is NULL.
 **/
 EFI_STATUS
 EFIAPI
diff --git a/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.c b/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.c
index ca13989..2d67279 100644
--- a/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.c
+++ b/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.c
@@ -714,7 +714,7 @@ ErrorExit:
   Starts the device controller.
   
   This function implments EFI_DRIVER_BINDING_PROTOCOL.Stop().
-  It stops this driver on Controller. Support stoping any child handles
+  It stops this driver on Controller. Support stopping any child handles
   created by this driver.
 
   @param  This              A pointer to the EFI_DRIVER_BINDING_PROTOCOL instance.
diff --git a/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.h b/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.h
index 5cfa704..8ecd4c0 100644
--- a/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.h
+++ b/IntelFrameworkModulePkg/Universal/Console/VgaClassDxe/VgaClass.h
@@ -134,7 +134,7 @@ VgaClassDriverBindingStart (
   Starts the device controller.
   
   This function implments EFI_DRIVER_BINDING_PROTOCOL.Stop().
-  It stops this driver on Controller. Support stoping any child handles
+  It stops this driver on Controller. Support stopping any child handles
   created by this driver.
 
   @param  This              A pointer to the EFI_DRIVER_BINDING_PROTOCOL instance.
diff --git a/IntelFrameworkModulePkg/Universal/DataHubDxe/DataHub.c b/IntelFrameworkModulePkg/Universal/DataHubDxe/DataHub.c
index 916586f..9a193d5 100644
--- a/IntelFrameworkModulePkg/Universal/DataHubDxe/DataHub.c
+++ b/IntelFrameworkModulePkg/Universal/DataHubDxe/DataHub.c
@@ -255,7 +255,7 @@ FindFilterDriverByEvent (
 /**
 
   Get a previously logged data record and the MonotonicCount for the next
-  availible Record. This allows all records or all records later 
+  available Record. This allows all records or all records later
   than a give MonotonicCount to be returned. If an optional FilterDriverEvent
   is passed in with a MonotonicCout of zero return the first record 
   not yet read by the filter driver. If FilterDriverEvent is NULL and 
@@ -264,7 +264,7 @@ FindFilterDriverByEvent (
   @param This                     Pointer to the EFI_DATA_HUB_PROTOCOL instance.
   @param MonotonicCount           Specifies the Record to return. On input, zero means
                                   return the first record. On output, contains the next
-                                  record to availible. Zero indicates no more records.
+                                  record to available. Zero indicates no more records.
   @param FilterDriverEvent        If FilterDriverEvent is not passed in a MonotonicCount 
                                   of zero, it means to return the first data record. 
                                   If FilterDriverEvent is passed in, then a MonotonicCount 
diff --git a/IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErr.c b/IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErr.c
index 48522c0..f64c541 100644
--- a/IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErr.c
+++ b/IntelFrameworkModulePkg/Universal/DataHubStdErrDxe/DataHubStdErr.c
@@ -56,7 +56,7 @@ DataHubStdErrEventHandler (
   //
   // If StdErr is not yet initialized just return a DEBUG print in the BDS
   // after consoles are connect will make sure data gets flushed properly
-  // when StdErr is availible.
+  // when StdErr is available.
   //
   if (gST == NULL) {
     return ;
diff --git a/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVol.c b/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVol.c
index 2ba09c4..65a292d 100644
--- a/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVol.c
+++ b/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVol.c
@@ -529,7 +529,7 @@ FvCheck (
       continue;
     }
     //
-    // double check boundry
+    // double check boundary
     //
     if (TestLength < sizeof (EFI_FFS_FILE_HEADER)) {
       break;
@@ -570,7 +570,7 @@ FvCheck (
         DEBUG ((EFI_D_ERROR, "Found a FFS3 formatted file: %g in a non-FFS3 formatted FV.\n", &((EFI_FFS_FILE_HEADER *) Ptr)->Name));
         Ptr = Ptr + FFS_FILE2_SIZE (Ptr);
         //
-        // Adjust Ptr to the next 8-byte aligned boundry.
+        // Adjust Ptr to the next 8-byte aligned boundary.
         //
         while (((UINTN) Ptr & 0x07) != 0) {
           Ptr++;
@@ -609,7 +609,7 @@ FvCheck (
       }
 
       //
-      // Adjust Ptr to the next 8-byte aligned boundry.
+      // Adjust Ptr to the next 8-byte aligned boundary.
       //
       while (((UINTN) Ptr & 0x07) != 0) {
         Ptr++;
diff --git a/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVolWrite.c b/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVolWrite.c
index 7f23b51..99385e0 100644
--- a/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVolWrite.c
+++ b/IntelFrameworkModulePkg/Universal/FirmwareVolume/FwVolDxe/FwVolWrite.c
@@ -782,7 +782,7 @@ FvCreateNewFile (
 
   //
   // First find a free space that can hold this image.
-  // Check alignment, FFS at least must be aligned at 8-byte boundry
+  // Check alignment, FFS at least must be aligned at 8-byte boundary
   //
   RequiredAlignment = GetRequiredAlignment (FileAttributes);
 
@@ -1513,7 +1513,7 @@ FvWriteFile (
 
   for (Index1 = 0; Index1 < NumberOfFiles; Index1++) {
     //
-    // Making Buffersize QWORD boundry, and add file tail.
+    // Making Buffersize QWORD boundary, and add file tail.
     //
     HeaderSize = sizeof (EFI_FFS_FILE_HEADER);
     ActualSize = FileData[Index1].BufferSize + HeaderSize;
diff --git a/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.c b/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.c
index 8c7019f..8dcb131 100644
--- a/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.c
+++ b/IntelFrameworkModulePkg/Csm/BiosThunk/KeyboardDxe/BiosKeyboard.c
@@ -934,7 +934,7 @@ KeyboardReadKeyStrokeWorker (
   }
 
   //
-  // Use TimerEvent callback funciton to check whether there's any key pressed
+  // Use TimerEvent callback function to check whether there's any key pressed
   //
   
   //
@@ -978,7 +978,7 @@ KeyboardReadKeyStrokeWorker (
   @param  ExtendedVerification  Whether perform the extra validation of keyboard. True: perform; FALSE: skip.
 
   @retval EFI_SUCCESS           The command byte is written successfully.
-  @retval EFI_DEVICE_ERROR      Errors occurred during reseting keyboard.
+  @retval EFI_DEVICE_ERROR      Errors occurred during resetting keyboard.
 
 **/
 EFI_STATUS
@@ -1176,8 +1176,8 @@ BiosKeyboardReset (
              );
 
   //
   // For reseting keyboard is not mandatory before booting OS and sometimes keyboard responses very slow,
   // so we only do the real reseting for keyboard when user asks, and normally during booting an OS, it's skipped.
   // Call CheckKeyboardConnect() to check whether keyboard is connected, if it is not connected,
   // Real reset will not do.
   //
@@ -1431,7 +1431,7 @@ BiosKeyboardWaitForKey (
   //
   gBS->Stall (1000);
   //
-  // Use TimerEvent callback funciton to check whether there's any key pressed
+  // Use TimerEvent callback function to check whether there's any key pressed
   //
   BiosKeyboardTimerHandler (NULL, BIOS_KEYBOARD_DEV_FROM_THIS (Context));
 
@@ -1795,7 +1795,7 @@ BiosKeyboardTimerHandler (
   // will be disabled after the thunk call finish, which means if user crazy input during int 9 being disabled, some keystrokes will be lost when 
   // KB device own hardware buffer overflows. And if the lost keystroke code is CTRL or ALT or SHIFT release code, these function key flags bit 
   // in BDA will not be updated. So the Int 16 will believe the CTRL or ALT or SHIFT is still pressed, and Int 16 will translate later scancode 
-  // to wrong ASCII code. We can increase the Thunk frequence to let Int 9 response in time, but this way will much hurt other dirvers 
+  // to wrong ASCII code. We can increase the Thunk frequence to let Int 9 response in time, but this way will much hurt other drivers
   // performance, like USB.
   //
   // 1. If CTRL or ALT release code is missed,  all later input keys will be translated to wrong ASCII codes which the Tiano cannot support. In 
@@ -1176,8 +1176,8 @@ BiosKeyboardReset (
 
   //
-  // For reseting keyboard is not mandatory before booting OS and sometimes keyboard responses very slow,
-  // so we only do the real reseting for keyboard when user asks, and normally during booting an OS, it's skipped.
+  // For resetting keyboard is not mandatory before booting OS and sometimes keyboard responses very slow,
+  // so we only do the real resetting for keyboard when user asks, and normally during booting an OS, it's skipped.
   // Call CheckKeyboardConnect() to check whether keyboard is connected, if it is not connected,
   // Real reset will not do.
diff --git a/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.c b/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.c
index 2e52723..e0ba053 100644
--- a/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.c
+++ b/IntelFrameworkModulePkg/Library/BaseUefiTianoCustomDecompressLib/BaseUefiTianoCustomDecompressLib.c
@@ -298,7 +298,7 @@ DecodeP (
 /**
   Reads code lengths for the Extra Set or the Position Set.
 
-  Read in the Extra Set or Pointion Set Length Arrary, then
+  Read in the Extra Set or Position Set Length Array, then
   generate the Huffman code mapping for them.
 
   @param  Sd      The global scratch data.
@@ -503,7 +503,7 @@ DecodeC (
     Sd->mBlockSize    = (UINT16) GetBits (Sd, 16);
 
     //
     // Read in the Extra Set Code Length Arrary,
     // Generate the Huffman code mapping table for Extra Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, NT, TBIT, 3);
@@ -512,13 +512,13 @@ DecodeC (
     }
 
     //
     // Read in and decode the Char&Len Set Code Length Arrary,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
     ReadCLen (Sd);
 
     //
     // Read in the Position Set Code Length Arrary, 
     // Generate the Huffman code mapping table for the Position Set.
     //
     Sd->mBadTableFlag = ReadPTLen (Sd, MAXNP, Sd->mPBit, (UINT16) (-1));
@@ -503,7 +503,7 @@ DecodeC (
 
     //
-    // Read in the Extra Set Code Length Arrary,
+    // Read in the Extra Set Code Length Array,
     // Generate the Huffman code mapping table for Extra Set.
     //
@@ -512,13 +512,13 @@ DecodeC (
 
     //
-    // Read in and decode the Char&Len Set Code Length Arrary,
+    // Read in and decode the Char&Len Set Code Length Array,
     // Generate the Huffman code mapping table for Char&Len Set.
     //
@@ -512,13 +512,13 @@ DecodeC (
 
     //
-    // Read in the Position Set Code Length Arrary, 
+    // Read in the Position Set Code Length Array,
     // Generate the Huffman code mapping table for the Position Set.
     //
-- 
2.10.1



  parent reply	other threads:[~2016-10-19  7:02 UTC|newest]

Thread overview: 79+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-10-19  7:01 [PATCH 00/33] Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 01/33] ArmPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19 15:15     ` Laszlo Ersek
2016-10-19 15:33       ` Leif Lindholm
2016-10-19  7:01 ` [PATCH 02/33] BaseTools: Fix typos in comments and variables Gary Lin
2016-10-19  7:30   ` Gao, Liming
2016-10-19  7:36   ` Zhu, Yonghong
2016-10-19  7:01 ` [PATCH 03/33] CorebootPayloadPkg: Fix typos in comments Gary Lin
2016-10-26 18:50   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 04/33] CorebootModulePkg: " Gary Lin
2016-10-26 18:41   ` Ma, Maurice
2016-10-19  7:01 ` [PATCH 05/33] CryptoPkg: " Gary Lin
2016-10-26  3:00   ` Long, Qin
2016-10-19  7:01 ` [PATCH 06/33] DuetPkg: " Gary Lin
2016-10-19  7:46   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 07/33] EdkCompatibilityPkg: " Gary Lin
2016-10-19  8:19   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 08/33] EmulatorPkg: Fix typos in comments and variables Gary Lin
2016-10-19 20:37   ` Jordan Justen
2016-10-20  8:16     ` Laszlo Ersek
2016-10-19  7:01 ` [PATCH 09/33] EmbeddedPkg: Fix typos in comments Gary Lin
2016-10-19 15:09   ` Ard Biesheuvel
2016-10-19  7:01 ` Gary Lin [this message]
2016-10-20  1:08   ` [PATCH 10/33] IntelFrameworkModulePkg: " Fan, Jeff
2016-10-19  7:01 ` [PATCH 11/33] IntelFrameworkPkg: " Gary Lin
2016-10-20  1:08   ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 12/33] IntelFspPkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 13/33] IntelFspWrapperPkg: " Gary Lin
2016-10-19  7:08   ` Yao, Jiewen
2016-10-19  7:01 ` [PATCH 14/33] IntelFsp2Pkg: " Gary Lin
2016-10-19  7:06   ` Yao, Jiewen
2016-10-19  7:12   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 15/33] IntelFsp2WrapperPkg: Fix a typo in the comment Gary Lin
2016-10-19  7:07   ` Yao, Jiewen
2016-10-19  7:11   ` Mudusuru, Giri P
2016-10-19  7:01 ` [PATCH 16/33] MdeModulePkg: BootManagerMenuApp: Fix typos in comments Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 17/33] MdeModulePkg/Bus: " Gary Lin
2016-10-19  7:01 ` [PATCH 18/33] MdeModulePkg/Core: " Gary Lin
2016-10-19  8:20   ` Tian, Feng
2016-10-19  7:01 ` [PATCH 19/33] MdeModulePkg/Include: " Gary Lin
2016-10-19  7:01 ` [PATCH 20/33] MdeModulePkg/Library: Fix typos in comments and variables Gary Lin
2016-10-19  7:01 ` [PATCH 21/33] MdeModulePkg/Universal: Fix typos in comments Gary Lin
2016-10-19  7:01 ` [PATCH 22/33] MdePkg: " Gary Lin
2016-10-19  8:21   ` Gao, Liming
2016-10-19  7:01 ` [PATCH 23/33] NetworkPkg: " Gary Lin
2016-10-19  7:21   ` Fu, Siyuan
2016-10-26  0:53   ` Fu, Siyuan
2016-10-19  7:01 ` [PATCH 24/33] Nt32Pkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:50   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 25/33] OptionRomPkg: Fix typos in comments Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19  7:01 ` [PATCH 26/33] OvmfPkg: " Gary Lin
2016-10-19  7:01 ` [PATCH 27/33] QuarkPlatformPkg: " Gary Lin
2016-10-25 20:53   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 28/33] QuarkSocPkg: " Gary Lin
2016-10-25 21:00   ` Kinney, Michael D
2016-10-19  7:01 ` [PATCH 29/33] SecurityPkg: " Gary Lin
2016-10-27  1:29   ` Zhang, Chao B
2016-11-14  3:12   ` Zhang, Chao B
2016-11-14  4:03     ` Gary Lin
2016-11-14  6:24       ` Gao, Liming
2016-11-14  8:30         ` Gary Lin
2016-10-19  7:01 ` [PATCH 30/33] ShellPkg: Fix typos in comments and variables Gary Lin
2016-10-19  7:51   ` Ni, Ruiyu
2016-10-19 20:29     ` Carsey, Jaben
2016-10-20  1:55       ` Gary Lin
2016-10-19  7:01 ` [PATCH 31/33] SourceLevelDebugPkg: Fix typos in comments Gary Lin
2016-10-19  7:46   ` Wu, Hao A
2016-10-19  7:01 ` [PATCH 32/33] UefiCpuPkg: " Gary Lin
2016-10-20  1:58   ` Fan, Jeff
2016-10-20  2:08     ` Gary Lin
2016-10-20  2:45       ` Fan, Jeff
2016-10-19  7:01 ` [PATCH 33/33] Vlv2TbltDevicePkg: " Gary Lin
2016-10-24  1:33   ` Wei, David
2016-10-19  7:28 ` [PATCH 00/33] Fix typos in comments and variables Zeng, Star
2016-10-19 14:50 ` Leif Lindholm

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-list from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20161019070138.16424-11-glin@suse.com \
    --to=devel@edk2.groups.io \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox